\n
\n\n\n\n
\n\n\n\n\n\n
\n\n\n
\n
\n
\n

## STD-1065 Lycoming Dowel-Stepped-.310-.251 Dia

\n
\n
\n
\n
$39.95/Each
\n
\n
\n
\n
\n
Part# 07-17502
MFR Model# STD-1065
\n\n\n\n\n\n\n
\n
\n
\n
\n\n\n\n\n
\n
\n

\n
\n\nFactory New Lycoming OEM Parts\n
\n

\n

\n
\n
\n\n
\n
\n
\n
\n
\n
\n
\n
\nLW-18639 Lycoming Lockplate Crankshaft Gear\n
\n
$8.50
\n
\n
\n
\n
\n
\nSTD-2246 Lycoming Bolt, .3125-24 X 1.00 Lg\n
\n
$35.50
\n
\n
\n
\n
\n
\n73818 Lycoming Drive Assembly Gasket\n
\n
$9.50
\n
\n
\n
\n
\n
\nLW-13353 Lycoming Oil Sump Gasket\n
\n
$15.75
\n
\n
\n
\n
\n
\nSuperior Sl-STD-2213 Screw\n
\n
$16.50
\n
\n
\n
\n
\n
\nLW-12681 Lycoming Magneto Gasket\n
\n
$2.80
\n
\n
\n
\n
\n
\n13S19646 Lycoming Gear-Crankshaft\n
\n
$498.00
\n
\n
\n
\n
\n
\n61183 Lycoming Accessory Adapter Gasket\n
\n
$1.75
\n
\n
\n
\n
\n
\nSuperior SL18639 Lockplate\n
\n
$2.40
\n
\n
\n
\n
\n
\n72091 Lycoming Ring-Oil Seal-.36I.D. X.10 Dia\n
\n
$2.15
\n
\n
\n
\n
\n
\n18M26104 Lycoming Connecting Rod Bearing\n
\n
$36.75
\n
\n
\n
\n
\n
\n78027 Lycoming Connecting Rod Bolt\n
\n
$52.75
\n
\n
\n
\n
\n
\n
\n
\nLycoming Dowels\n
\n
$9.70
\n
\n
\n
\n
\n
\nLycoming Gaskets\n
\n
$4.70
\n
\n
\n
\n
\n
\nBrackett Replacement Element BA6108\n
\n
$14.50
\n
\n
\n
\n
\n
\nLycoming Intake Gasket - 71973\n
\n
$2.15
\n
\n
\n
\n
\n
\n77611 Lycoming Exhaust Flange Gasket\n
\n
$13.50
\n
\n
\n
\n
\n
\nBrackett Air Filters\n
\n
$37.95
\n
\n
\n
\n
\n
\nPhillips 66 X/C Aviation Oil 20W50\n
\n
$1528.00
\n
\n
\n
\n
\n
\nLycoming At Overhaul Parts Replacement List - IO-540-C4B5 D4A5\n
\n
$207.95
\n
\n
\n
\n
\n
\nLW-18639 Lycoming Lockplate Crankshaft Gear\n
\n
$8.50
\n
\n
\n
\n
\n
\nLW12681 Lycoming Magneto Gasket\n
\n
$2.80
\n
\n
\n
\n
\n
\nAN900 (MS35769) Copper Gaskets - Crush Washers\n
\n
$3.55
\n
\n
\n
\n
\n
\nLycoming At Overhaul Parts Replacement List - IO-720-A1A A1B C1B D1B Narrow Deck\n
\n
$8.80
\n
\n
\n
\n
\n
\nLycoming Assembly Drive Gasket 73818\n
\n
$9.50
\n
\n
\n
\n
\n
\nMillennium Cylinder Power Assembly Kit Contents SL32006W-A20P For: O-320-B D;IO-320-B D;Aio-320-A B C;AEIO-320-D Lio-320-B\n
\n
$47.85
\n
\n
\n
\n
\n
\nMillennium Cylinder Power Assembly Kit Contents SL36006N-A21P For: O-360-B D; O-540-B (Narrow Deck)\n
\n
$54.85
\n
\n
\n
\n
\n
\nLycoming At Overhaul Parts Replacement List - O-540-B Series E Series G1A5 H Series\n
\n
$3.35
\n
\n
\n
\n
\n
\nLycoming At Overhaul Parts Replacement List - O-360-A Series B2D & C Series D Series\n
\n
$3.35
\n
\n
\n
\n
\n
\nLycoming At Overhaul Parts Replacement List - IO-720-A1A A1B C1B D1B Wide Deck\n
\n
$3.35
\n
\n
\n
\n
\n
\nMillennium Cylinder Power Assembly Kit Contents SL32000Wh-A20P For: O-320-H2Ad H3Ad\n
\n
$54.85
\n
\n
\n
\n
\n
\nAeroshell Grease\n
\n
$173.00
\n
\n
\n
\n
\n
\n
\n
\n\n
\n
\n\n
\n\n\n\n
\n
\n